SISCone : Main Page

# SISCone Documentation

### Version 3.0.5

SISCone is a Seedless Infrared Safe Cone jet algorithm.

It was developped by Gavin Salam and Gregory Soyez. It is available as a library, as a standalone program or as a FastJet (>= 2.1) plugin.

News (April 24 2020): We have released a new version of SISCone (v3.0.5). This minor release fixes a signed/unsigned warning in bitshift operations (thanks to Andrii Verbytskyi). Relative to the 2.0.X series, SISCone 3.0.X adds the option of running SISCone with progressive removal (instead of the standard split-merge step). This version will be available in FastJet(>=3.3.4).

The algorithm is described in the publication JHEP 05 (2007) 086 [arXiv:0704.0292 [hep-ph]]. See the links below for more detailed information.

Useful links

- How to use SISCone
- Download SISCone
- Description of the algorithm
- Algorithm performance
- Developer documentation (built from the code using doxygen)
- SISCone webpage on HEPForge

Home
Contacts: Gregory Soyez Gavin Salam